@@ -15,7 +15,7 @@ regex = re.compile(r'^((?P<weeks>[\.\d]+?)w)? *'
                    r'^((?P<days>[\.\d]+?)d)? *'
                    r'((?P<hours>[\.\d]+?)h)? *'
                    r'((?P<minutes>[\.\d]+?)m)? *'
-                   r'((?P<seconds>[\.\d]+?)s)?$')
+                   r'((?P<seconds>[\.\d]+?)s?)?$')
 
 
 def parse_time(time_str):
